@@ -28,6 +28,20 @@ control_parsnip <- function(verbosity = 1L, catch = FALSE) {
   res
 }
 
+check_control <- function(x) {
+  if (!is.list(x))
+    rlang::abort("control should be a named list.")
+  if (!isTRUE(all.equal(sort(names(x)), c("catch", "verbosity"))))
+    rlang::abort("control should be a named list with elements 'verbosity' and 'catch'.")
+  # based on ?is.integer
+  int_check <- function(x, tol = .Machine$double.eps^0.5) abs(x - round(x)) < tol
+  if (!int_check(x$verbosity))
+    rlang::abort("verbosity should be an integer.")
+  if (!is.logical(x$catch))
+    rlang::abort("catch should be a logical.")
+  x
+}
+
 #' @export
 print.control_parsnip <- function(x, ...) {
   cat("parsnip control object\n")
