@@ -27,6 +27,6 @@
 #' @export
 #' @keywords internal
 fit_control <- function(verbosity = 1L, catch = FALSE) {
-  lifecycle::deprecate_soft("0.1.8", "fit_control()", "control_parsnip()")
+  lifecycle::deprecate_warn("0.1.8", "fit_control()", "control_parsnip()")
   control_parsnip(verbosity = verbosity, catch = catch)
 }
