@@ -18,6 +18,7 @@
 #' @param prod_degree The highest possible interaction degree.
 #' @param prune_method The pruning method.
 #'
+#' @templateVar modeltype mars
 #' @template spec-details
 #'
 #' @template spec-references
@@ -86,6 +87,9 @@ translate.mars <- function(x, engine = x$engine, ...) {
     message("Used `engine = 'earth'` for translation.")
     engine <- "earth"
   }
+  if (engine == "earth") {
+    load_libs(x, quiet = TRUE, attach = TRUE)
+  }
   # If classification is being done, the `glm` options should be used. Check to
   # see if it is there and, if not, add the default value.
   if (x$mode == "classification") {
@@ -122,7 +126,8 @@ check_args.mars <- function(object) {
 
 earth_submodel_pred <- function(object, new_data, terms = 2:3, ...) {
   load_libs(object, quiet = TRUE, attach = TRUE)
-  map_dfr(terms, earth_reg_updater, object = object, newdata = new_data, ...)
+  map(terms, earth_reg_updater, object = object, newdata = new_data, ...) %>%
+    purrr::list_rbind()
 }
 
 earth_reg_updater <- function(num, object, new_data, ...) {
@@ -146,9 +151,6 @@ earth_reg_updater <- function(num, object, new_data, ...) {
 #' @export
 multi_predict._earth <-
   function(object, new_data, type = NULL, num_terms = NULL, ...) {
-    if (any(names(enquos(...)) == "newdata"))
-      rlang::abort("Did you mean to use `new_data` instead of `newdata`?")
-
     load_libs(object, quiet = TRUE, attach = TRUE)
 
     if (is.null(num_terms))
@@ -183,8 +185,9 @@ multi_predict._earth <-
     }
 
     res <-
-      map_df(num_terms, earth_by_terms, object = object,
-             new_data = new_data, type = type, ...)
+      map(num_terms, earth_by_terms, object = object,
+          new_data = new_data, type = type, ...) %>%
+      purrr::list_rbind()
     res <- arrange(res, .row, num_terms)
     res <- split(res[, -1], res$.row)
     names(res) <- NULL
@@ -196,6 +199,6 @@ earth_by_terms <- function(num_terms, object, new_data, type, ...) {
   pred <- predict(object, new_data = new_data, type = type)
   nms <- names(pred)
   pred[["num_terms"]] <- num_terms
-  pred[[".row"]] <- 1:nrow(new_data)
+  pred[[".row"]] <- seq_len(nrow(new_data))
   pred[, c(".row", "num_terms", nms)]
 }
