@@ -7,7 +7,7 @@
 #' @export
 #' @keywords internal
 varying <- function() {
-  lifecycle::deprecate_soft("0.1.8", "varying()", "hardhat::tune()")
+  lifecycle::deprecate_warn("0.1.8", "varying()", "hardhat::tune()")
   quote(varying())
 }
 
@@ -68,7 +68,7 @@ generics::varying_args
 #' @keywords internal
 #' @export
 varying_args.model_spec <- function(object, full = TRUE, ...) {
-  lifecycle::deprecate_soft("0.1.8", "varying_args()", "tune_args()")
+  lifecycle::deprecate_warn("0.1.8", "varying_args()", "tune_args()")
 
   # use the model_spec top level class as the id
   id <- class(object)[1]
@@ -104,7 +104,7 @@ varying_args.model_spec <- function(object, full = TRUE, ...) {
 #' @export
 #' @rdname varying_args
 varying_args.recipe <- function(object, full = TRUE, ...) {
-  lifecycle::deprecate_soft("0.1.8", "varying_args()", "tune_args()")
+  lifecycle::deprecate_warn("0.1.8", "varying_args()", "tune_args()")
 
   steps <- object$steps
 
@@ -112,13 +112,13 @@ varying_args.recipe <- function(object, full = TRUE, ...) {
     return(varying_tbl())
   }
 
-  map_dfr(object$steps, varying_args, full = full)
+  map(object$steps, varying_args, full = full) %>% purrr::list_rbind()
 }
 
 #' @export
 #' @rdname varying_args
 varying_args.step <- function(object, full = TRUE, ...) {
-  lifecycle::deprecate_soft("0.1.8", "varying_args()", "tune_args()")
+  lifecycle::deprecate_warn("0.1.8", "varying_args()", "tune_args()")
 
   # Unique step id
   id <- object$id
