@@ -27,7 +27,7 @@ ctrl <- control_parsnip(verbosity = 0, catch = FALSE)
 test_that('model fitting', {
   skip_on_cran()
   skip_if_not_installed("keras")
-  skip_if(is.null(tensorflow::tf_version()))
+  skip_if(!is_tf_ok())
 
   set_tf_seed(257)
 
@@ -97,7 +97,7 @@ test_that('model fitting', {
 test_that('classification prediction', {
   skip_on_cran()
   skip_if_not_installed("keras")
-  skip_if(is.null(tensorflow::tf_version()))
+  skip_if(!is_tf_ok())
 
   library(keras)
 
@@ -142,7 +142,7 @@ test_that('classification prediction', {
 test_that('classification probabilities', {
   skip_on_cran()
   skip_if_not_installed("keras")
-  skip_if(is.null(tensorflow::tf_version()))
+  skip_if(!is_tf_ok())
 
   library(keras)
 
